@@ -1,19 +1,16 @@
-from __future__ import unicode_literals
-
 from django.conf import settings
-from django.template import Context
 from django.utils.module_loading import import_string
 
 
 def link_components(request, user=None):
     protocol = 'https' if request.is_secure() else 'http'
-    hostname = getattr(settings, 'HOSTNAME', request.get_host())
+    hostname = request.get_host()
 
     return {"protocol": protocol, "hostname": hostname}
 
 
 def build_email_context(request=None, user=None):
-    context = Context({'user': user})
+    context = {'user': user}
 
     processors = []
     collect = []
